@@ -15,6 +15,8 @@ from nsnitro.nsresources.nsserver import NSServer
 from nsnitro.nsresources.nscsvserver import NSCSVServer
 from nsnitro.nsresources.nsacl import NSAcl
 from nsnitro.nsresources.nsacls import NSAcls
+from nsnitro.nsresources.nshanode import NSHANode
+from nsnitro.nsresources.nsservicegroupserverbinding import NSServiceGroupServerBinding
 
 if __name__ == "__main__":
         parser = argparse.ArgumentParser(description='Netscaler NITRO controller')
@@ -61,6 +63,8 @@ if __name__ == "__main__":
 
         parser.add_argument('--saveconfig', action='store_true', help='save loadbalancer config')
 
+        parser.add_argument('--getprimarylb', action='store_true', help='If you netscaler is in a cluster show the node that is primary')
+
         parser.add_argument('--dargs', action='store_true', help='show service')
         # additional arguments
         parser.add_argument('--port', metavar='PORT', help='port number')
@@ -80,6 +84,12 @@ if __name__ == "__main__":
         parser.add_argument('--clearacls', action='store_true', help='clear acls')
         parser.add_argument('--renumberacls', action='store_true', help='renumber acls')
 
+        parser.add_argument('--bindservertoservicegroup', action='store_true', help='bind a server to a service group')
+        parser.add_argument('--unbindserverfromservicegroup', action='store_true', help='bind a server to a service group')
+        parser.add_argument('--servername', action='store', help='server object to manipulate')
+        parser.add_argument('--servicegroupname', action='store', help='service group object to manipulate')
+        parser.add_argument('--serviceport', action='store', help='service port')
+
         args = parser.parse_args()
 
         if args.dargs:
@@ -91,6 +101,45 @@ if __name__ == "__main__":
         try:
                 nitro.login()
 
+                if args.bindservertoservicegroup:
+                  if not args.servername or not args.servicegroupname or not args.serviceport: 
+                    print "--servername, --servicename, and --serviceport are required for binding a server to a service group"
+                    nitro.logout()
+                    sys.exit(0)
+                  else:
+                    svcgrpbinding=NSServiceGroupServerBinding()
+                    svcgrpbinding.set_servername(args.servername)
+                    svcgrpbinding.set_servicegroupname(args.servicegroupname)
+                    svcgrpbinding.set_port(args.serviceport)
+                    try:
+                      NSServiceGroupServerBinding.add(nitro, svcgrpbinding)
+                      print "bound server %s to service group %s on port %s" % (args.servername, args.servicegroupname, args.serviceport)
+                    except nsnitro.nsexceptions.nsexceptions.NSNitroNserrExist as e:
+                      print "Error: ", e.message
+                    finally:
+                      nitro.logout()
+                      sys.exit(0)
+                    
+                if args.unbindserverfromservicegroup:
+                  if not args.servername or not args.servicegroupname or not args.serviceport: 
+                    print "--servername, --servicename, and --serviceport are required for binding a server to a service group"
+                    nitro.logout()
+                    sys.exit(0)
+                  else:
+                    svcgrpbinding=NSServiceGroupServerBinding()
+                    svcgrpbinding.set_servername(args.servername)
+                    svcgrpbinding.set_servicegroupname(args.servicegroupname)
+                    svcgrpbinding.set_port(args.serviceport)
+                    try:
+                      NSServiceGroupServerBinding.delete(nitro, svcgrpbinding)
+                      print "unbound server %s from service group %s on port %s" % (args.servername, args.servicegroupname, args.serviceport)
+                    except nsnitro.nsexceptions.nsexceptions.NSNitroNserrNoent as e:
+                      print "Error: ", e.message
+                    finally:
+                      nitro.logout()
+                      sys.exit(0)
+                    
+
                 if args.addlbvserver:
                         if not args.port or not args.ip:
                           print "--ip and --port are required for adding LB Vserver"
@@ -122,6 +171,16 @@ if __name__ == "__main__":
                         nitro.logout()
                         sys.exit(0)
 
+                if args.getprimarylb:
+                        ha_node = NSHANode()
+                        for node in ha_node.get_all(nitro):
+                            state = node.get_state().lower()
+                            if state == 'primary':
+                                print(node.get_ipaddress())
+                                break
+                        nitro.logout()
+                        sys.exit(0)
+
                 if args.disablelbvserver:
                         lbvserver = NSLBVServer()
                         lbvserver.set_name(args.disablelbvserver)
