@@ -28,6 +28,7 @@ from nshanode import NSHANode
 from nsip import NSIP
 from nsiptunnel import NSIPTunnel
 from nsroute import NSRoute
+from nsversion import NSVersion
 from nsvlan import NSVLAN
 from nsvlaninterfacebinding import NSVLANInterfaceBinding
 from nsvlannsipbinding import NSVLANNSIPBinding
@@ -40,6 +41,11 @@ from nsacl import NSAcl
 from nsacls import NSAcls
 from nspbr import NSPbr
 from nspbrs import NSPbrs
+from authenticationtacacsaction import AuthTacacsAction
+from authenticationtacacspolicy import AuthTacacsPolicy
+from snmpcommunity import SNMPCommunity
+from systemuser import SystemUser
+from systemglobalauthenticationtacacspolicybinding import SystemGlobalAuthTacacsPolicyBinding
 
 __all__ = ['NSBaseResource',
            'NSConfig',
@@ -71,6 +77,7 @@ __all__ = ['NSBaseResource',
            'NSIP',
            'NSIPTunnel',
            'NSRoute',
+           'NSVersion',
            'NSVLAN',
            'NSVLANInterfaceBinding',
            'NSVLANNSIPBinding',
@@ -82,5 +89,10 @@ __all__ = ['NSBaseResource',
            'NSAcl',
            'NSAcls',
            'NSPbr',
-           'NSPbrs'
+           'NSPbrs',
+           'AuthTacacsAction',
+           'AuthTacacsPolicy',
+           'SNMPCommunity',
+           'SystemGlobalAuthTacacsPolicyBinding',
+           'SystemUser'
            ]
